package market.Mes.Shift.mapper;
import java.util.HashMap;
import java.util.List;

import market.Mes.Shift.vo.MesShiftDNotes;

import com.hnshituo.orm.GenericMapper;

public interface MesShiftDNotesMapper extends GenericMapper<MesShiftDNotes,Object> {

	List<HashMap> doQueryWeb_yuanliao4mm(String memo1, String memo2);

	List<HashMap> doQueryWeb_yuanliao3mm(String memo1, String memo2);

	List<HashMap> doQueryWeb_yuanliaoanneal(String memo1, String memo2);

	List<HashMap> doQueryWeb_yuanliaotpm(String memo1, String memo2);

	List<HashMap> doQueryWeb_yuanliaorcm(String memo1, String memo2);

	List<HashMap> doQueryWeb_yuanliaoplm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping4mm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping3mm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpinganneal(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingtpm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingrcm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingplm(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping4mm_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping3mm_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpinganneal_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingtpm_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingrcm_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingplm_weipan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping4mm_feijihua(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping3mm_feijihua(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpinganneal_feijihua(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingtpm_feijihua(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingrcm_feijihua(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingplm_feijihua(String memo1, String memo2);
	
	List<HashMap> doQueryWeb_chengping4mm_feijihuawaiguan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping3mm_feijihuawaiguan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpinganneal_feijihuawaiguan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingtpm_feijihuawaiguan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingrcm_feijihuawaiguan(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingplm_feijihuawaiguan(String memo1, String memo2);
	
	List<HashMap> doQueryWeb_chengping4mm_feijihuagongcha(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengping3mm_feijihuagongcha(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpinganneal_feijihuagongcha(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingtpm_feijihuagongcha(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingrcm_feijihuagongcha(String memo1, String memo2);

	List<HashMap> doQueryWeb_chengpingplm_feijihuagongcha(String memo1, String memo2);
	
}
