/***文档注释***********************************************
 * 作者            ：
 * 创建日期     ：2018-03-27
 * 描述            ：岗位交接班班中情况记录表
 * 注意事项     ：
 * 遗留BUG   ：
 * 修改日期     ：
 * 修改人员     ：
 * 修改内容     ：
***********************************************************/
package market.Mes.Shift.impl;
import market.Com.vo.CommonPage;
import market.Com.vo.ResultModel;
import market.Mes.Shift.mapper.MesShiftDNotesMapper;
import market.Mes.Shift.service.MesShiftDNotesService;
import market.Mes.Shift.vo.MesShiftDNotes;
import market.Mes.Shift.vo.MesShiftM;

import com.hnshituo.basic.service.impl.BaseServiceImpl;
import com.hnshituo.basic.spring.remoting.annotation.RemoteService;

@RemoteService(path="MesShiftDNotesService")
public class MesShiftDNotesServiceImpl extends BaseServiceImpl<MesShiftDNotes,Object> implements MesShiftDNotesService {
	
	/**
	 * 查询原料(t)
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_yuanliao(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliao4mm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliao3mm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliaoanneal(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliaotpm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliaorcm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_yuanliaoplm(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	
	/**
	 * 查询产量(t)
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_chengping(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping4mm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping3mm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpinganneal(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingtpm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingrcm(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingplm(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	/**
	 * 查询待判（未判定）(t)
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_daipan(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping4mm_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping3mm_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpinganneal_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingtpm_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingrcm_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingplm_weipan(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	
	/**
	 * 非计划总量(t)
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_feijihua(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping4mm_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping3mm_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpinganneal_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingtpm_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingrcm_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingplm_feijihua(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	
	/**
	 * 1 外观非计划
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_feijihuawaiguan(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping4mm_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping3mm_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpinganneal_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingtpm_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingrcm_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingplm_feijihuawaiguan(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	
	/**
	 * 3 公差非计划
	 * @param sum
	 * memo1: V_MCH_CODE 机台代码
	 * memo2: V_DATE  
	 * @return
	 */
	public ResultModel doQueryWeb_feijihuagongcha(CommonPage<MesShiftM> sum){
		ResultModel rm=new ResultModel();
		try{
			if(sum.getMemo1().equals("M0001") || sum.getMemo1().equals("M0002")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping4mm_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0003")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengping3mm_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0004") || sum.getMemo1().equals("M0005") || sum.getMemo1().equals("M0006") 
					|| sum.getMemo1().equals("M0009")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpinganneal_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0007")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingtpm_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0008")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingrcm_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			if(sum.getMemo1().equals("M0010")){
				rm.setData(this.getMapper(MesShiftDNotesMapper.class).doQueryWeb_chengpingplm_feijihuagongcha(sum.getMemo1(),sum.getMemo2()));
			}
			
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！\n"+ex.getMessage());
		}
		return rm;
	}
	
	
	
}
